summaryrefslogtreecommitdiffstats
path: root/gui/polkitqt1-gui-action.h
diff options
context:
space:
mode:
Diffstat (limited to 'gui/polkitqt1-gui-action.h')
-rw-r--r--gui/polkitqt1-gui-action.h38
1 files changed, 19 insertions, 19 deletions
diff --git a/gui/polkitqt1-gui-action.h b/gui/polkitqt1-gui-action.h
index fed4cdc12..0b8763e8d 100644
--- a/gui/polkitqt1-gui-action.h
+++ b/gui/polkitqt1-gui-action.h
@@ -24,9 +24,9 @@
#include "polkitqt1-export.h"
-#include <QtGui/QAction>
+#include <TQtGui/TQAction>
-namespace PolkitQt1
+namespace PolkitTQt1
{
namespace Gui
@@ -44,16 +44,16 @@ namespace Gui
* given action.
*
* Most of the times, you would want to use this class combined
- * with a QAbstractButton. In this case, you can use the more
+ * with a TQAbstractButton. In this case, you can use the more
* comfortable ActionButton class that manages button's properties
* update for you.
*
* \see ActionButton
*/
-class POLKITQT1_EXPORT Action : public QAction
+class POLKITQT1_EXPORT Action : public TQAction
{
Q_OBJECT
- Q_DISABLE_COPY(Action)
+ TQ_DISABLE_COPY(Action)
public:
enum State {
@@ -77,7 +77,7 @@ public:
* \param actionId the PolicyKit action Id (e.g.: org.freedesktop.policykit.read)
* \param parent the object parent
*/
- explicit Action(const QString &actionId = QString(), QObject *parent = 0);
+ explicit Action(const TQString &actionId = TQString(), TQObject *parent = 0);
~Action();
Q_SIGNALS:
@@ -134,7 +134,7 @@ public:
*
* \param actionId The new action ID
*/
- void setPolkitAction(const QString &actionId);
+ void setPolkitAction(const TQString &actionId);
/**
* Returns the current action ID.
@@ -142,7 +142,7 @@ public:
* \return The action ID
*
*/
- QString actionId() const;
+ TQString actionId() const;
/**
* Sets the text for the current action. This will
@@ -151,7 +151,7 @@ public:
* \param states the states of the Polkit action on which the setting
* will be applied
*/
- void setText(const QString &text, States states = All);
+ void setText(const TQString &text, States states = All);
/**
* Sets the tooltip for the current action. This will
@@ -160,7 +160,7 @@ public:
* \param states the states of the Polkit action on which the setting
* will be applied
*/
- void setToolTip(const QString &toolTip, States states = All);
+ void setToolTip(const TQString &toolTip, States states = All);
/**
* Sets the whatsthis for the current action. This will
@@ -169,18 +169,18 @@ public:
* \param states the states of the Polkit action on which the setting
* will be applied
*/
- void setWhatsThis(const QString &whatsThis, States states = All);
+ void setWhatsThis(const TQString &whatsThis, States states = All);
/**
* Sets the icon for the current action. This will
* be shown only in the states specified in the \c states parameter.
* \note You need to pass a QIcon here. You can easily
* create one from a Pixmap, or pass a KIcon
* \param icon the new icon for the action
* \param states the states of the Polkit action on which the setting
* will be applied
*/
- void setIcon(const QIcon &icon, States states = All);
+ void setIcon(const TQIcon &icon, States states = All);
/**
* Sets whether the current action is visible or not. This will
@@ -216,7 +216,7 @@ public:
* \param state The state to be checked
* \returns The text shown when the action is in the specified state
*/
- QString text(State state = None) const;
+ TQString text(State state = None) const;
/**
* Gets the tooltip of the action when it is in the specified state
@@ -225,7 +225,7 @@ public:
* \param state The state to be checked
* \returns The tooltip shown when the action is in the specified state
*/
- QString toolTip(State state = None) const;
+ TQString toolTip(State state = None) const;
/**
* Gets the whatsThis of the action when it is in the specified state
@@ -233,7 +233,7 @@ public:
* \param state The state to be checked
* \returns The whatsThis shown when the action is in the specified state
*/
- QString whatsThis(State state = None) const;
+ TQString whatsThis(State state = None) const;
/**
* Gets the icon of the action when it is in the specified state
@@ -242,7 +242,7 @@ public:
* \param state The state to be checked
* \returns The icon shown when the action is in the specified state
*/
- QIcon icon(State state = None) const;
+ TQIcon icon(State state = None) const;
/**
* Gets whether the action is visible or not when it is in the specified state
@@ -286,7 +286,7 @@ public:
*
* \return \c true if the actionId is the same as this object's one
*/
- bool is(const QString &actionId) const;
+ bool is(const TQString &actionId) const;
private:
class Private;
@@ -299,6 +299,6 @@ private:
}
-Q_DECLARE_OPERATORS_FOR_FLAGS(PolkitQt1::Gui::Action::States)
+Q_DECLARE_OPERATORS_FOR_FLAGS(PolkitTQt1::Gui::Action::States)
#endif
@@ -169,18 +169,18 @@ public:
* Sets the icon for the current action. This will
* be shown only in the states specified in the \c states parameter.
- * \note You need to pass a QIcon here. You can easily
+ * \note You need to pass a TQIcon here. You can easily
* create one from a Pixmap, or pass a KIcon
* \param icon the new icon for the action